{% extends "admin/base_site.html" %}
{% load i18n static %}
{% block breadcrumbs %}
    <div class="page-pretitle">
        <ol class="breadcrumb">
            <li class="breadcrumb-item">
                <a href="{% url 'admin:index' %}">{% translate "Home" %}</a>
            </li>
        </ol>
    </div>
{% endblock breadcrumbs %}
{% block content %}
    {% if app_label %}
        <div id="content-main">{% include "admin/app_list.html" with app_list=app_list show_changelinks=True %}</div>
    {% else %}
        <div id="content-main">Hi Dashboard</div>
    {% endif %}
{% endblock content %}
